from skimage.feature import greycomatrix, greycoprops
import numpy as np

@staticmethod
def texture_features(distances, angles, properties, image):
    """
    @brief Calc the texture properties of a greyscale image

    Calculate the property passed as parameter of the function.
    ref: http://scikit-image.org/docs/0.7.0/api/skimage.feature.texture.html

    :param distances: List of pixel pair distance offsets
    :param angles: List of pixel pair angles in radians.
    :param properties: Array of Strings. The feature that you want to calculate. 'contrast', 'dissimilarity'
    'homogeneity', 'ASM', 'energy', 'correlation'.
    :param image: Greyscale image in uint8
    :return:
    """
    glcm = greycomatrix(image, distances=distances, angles=angles, symmetric=True, normed=True)

    return np.hstack([greycoprops(glcm, prop).ravel() for prop in properties])




from .contours import Contours
from .masks import Masks
from .texture import texture_features

Features_mask = {'Solidity': Masks.solidity, 'CH Perimeter': Masks.convex_hull_perimeter,
                 'CH Area': Masks.convex_hull_area, 'BB Area': Masks.bounding_box_area,
                 'Rectangularity': Masks.rectangularity, 'Min r': Masks.min_r, 'Max r': Masks.max_r,
                 'Feret': Masks.feret, 'Breadth': Masks.breadth,
                 'Circularity': Masks.circularity, 'Roundness': Masks.roundness, 'Feret Angle': Masks.feret_angle,
                 'Eccentricity': Masks.eccentricity,
                 'Center': Masks.center, 'Sphericity': Masks.sphericity, 'Aspect Ratio': Masks.aspect_ratio,
                 'Area equivalent': Masks.area_equivalent_diameter,
                 'Perimeter equivalent': Masks.perimeter_equivalent_diameter,
                 'Equivalent elipse area': Masks.equivalent_ellipse_area,
                 'Compactness': Masks.compactness, 'Area': Masks.area, 'Convexity': Masks.convexity,
                 'Shape': Masks.shape, 'Perimeter': Masks.perimeter,
                 }
